@@ -58,9 +58,8 @@ new S3ToStepFunction(scope: Construct, id: string, props: S3ToStepFunctionProps)
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployBucket?|`boolean`|Whether to create a S3 Bucket or use an existing S3 Bucket|
-|existingBucketObj?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Existing instance of S3 Bucket object|
-|bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|Optional user provided props to override the default props for S3 Bucket|
+|existingBucketObj?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.|
+|bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|User provided props to override the default props for the S3 Bucket.|
 |stateMachineProps|[`sfn.StateMachineProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachineProps.html)|Optional user provided props to override the default props for sfn.StateMachine|
 |eventRuleProps?|[`events.RuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.RuleProps.html)|Optional user provided eventRuleProps to override the defaults|
 |deployCloudTrail?|`boolean`|Whether to deploy a Trail in AWS CloudTrail to log API events in Amazon S3|
@@ -128,17 +127,30 @@ import aws_cdk.aws_stepfunctions
 import aws_cdk.core
 
 
-class S3ToStepFunction(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-s3-step-function.S3ToStepFunction"):
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps, bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps]=None, deploy_bucket: typing.Optional[bool]=None, deploy_cloud_trail: typing.Optional[bool]=None, event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps]=None, existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket]=None) -> None:
+class S3ToStepFunction(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-s3-step-function.S3ToStepFunction",
+):
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        deploy_cloud_trail: typing.Optional[bool] = None,
+        event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
+        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
-        :param bucket_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
-        :param deploy_bucket: Whether to create a S3 Bucket or use an existing S3 Bucket. If set to false, you must provide S3 Bucket as ``existingBucketObj`` Default: - true
+        :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param deploy_cloud_trail: Whether to deploy a Trail in AWS CloudTrail to log API events in Amazon S3. Default: - true
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
-        :param existing_bucket_obj: Existing instance of S3 Bucket object. If ``deployBucket`` is set to false only then this property is required Default: - None
+        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
 
         access:
         :access:: public
@@ -147,7 +159,13 @@ class S3ToStepFunction(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_typ
         summary:
         :summary:: Constructs a new instance of the S3ToStepFunction class.
         """
-        props = S3ToStepFunctionProps(state_machine_props=state_machine_props, bucket_props=bucket_props, deploy_bucket=deploy_bucket, deploy_cloud_trail=deploy_cloud_trail, event_rule_props=event_rule_props, existing_bucket_obj=existing_bucket_obj)
+        props = S3ToStepFunctionProps(
+            state_machine_props=state_machine_props,
+            bucket_props=bucket_props,
+            deploy_cloud_trail=deploy_cloud_trail,
+            event_rule_props=event_rule_props,
+            existing_bucket_obj=existing_bucket_obj,
+        )
 
         jsii.create(S3ToStepFunction, self, [scope, id, props])
 
@@ -172,31 +190,56 @@ class S3ToStepFunction(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "cloudtrail")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-s3-step-function.S3ToStepFunctionProps", jsii_struct_bases=[], name_mapping={'state_machine_props': 'stateMachineProps', 'bucket_props': 'bucketProps', 'deploy_bucket': 'deployBucket', 'deploy_cloud_trail': 'deployCloudTrail', 'event_rule_props': 'eventRuleProps', 'existing_bucket_obj': 'existingBucketObj'})
-class S3ToStepFunctionProps():
-    def __init__(self, *, state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps, bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps]=None, deploy_bucket: typing.Optional[bool]=None, deploy_cloud_trail: typing.Optional[bool]=None, event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps]=None, existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-s3-step-function.S3ToStepFunctionProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "state_machine_props": "stateMachineProps",
+        "bucket_props": "bucketProps",
+        "deploy_cloud_trail": "deployCloudTrail",
+        "event_rule_props": "eventRuleProps",
+        "existing_bucket_obj": "existingBucketObj",
+    },
+)
+class S3ToStepFunctionProps:
+    def __init__(
+        self,
+        *,
+        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
+        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        deploy_cloud_trail: typing.Optional[bool] = None,
+        event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
+        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+    ) -> None:
         """
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
-        :param bucket_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
-        :param deploy_bucket: Whether to create a S3 Bucket or use an existing S3 Bucket. If set to false, you must provide S3 Bucket as ``existingBucketObj`` Default: - true
+        :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param deploy_cloud_trail: Whether to deploy a Trail in AWS CloudTrail to log API events in Amazon S3. Default: - true
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
-        :param existing_bucket_obj: Existing instance of S3 Bucket object. If ``deployBucket`` is set to false only then this property is required Default: - None
+        :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
 
         summary:
         :summary:: The properties for the S3ToStepFunction Construct
         """
-        if isinstance(state_machine_props, dict): state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
-        if isinstance(bucket_props, dict): bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
-        if isinstance(event_rule_props, dict): event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+        if isinstance(state_machine_props, dict):
+            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(
+                **state_machine_props
+            )
+        if isinstance(bucket_props, dict):
+            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+        if isinstance(event_rule_props, dict):
+            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         self._values = {
-            'state_machine_props': state_machine_props,
+            "state_machine_props": state_machine_props,
         }
-        if bucket_props is not None: self._values["bucket_props"] = bucket_props
-        if deploy_bucket is not None: self._values["deploy_bucket"] = deploy_bucket
-        if deploy_cloud_trail is not None: self._values["deploy_cloud_trail"] = deploy_cloud_trail
-        if event_rule_props is not None: self._values["event_rule_props"] = event_rule_props
-        if existing_bucket_obj is not None: self._values["existing_bucket_obj"] = existing_bucket_obj
+        if bucket_props is not None:
+            self._values["bucket_props"] = bucket_props
+        if deploy_cloud_trail is not None:
+            self._values["deploy_cloud_trail"] = deploy_cloud_trail
+        if event_rule_props is not None:
+            self._values["event_rule_props"] = event_rule_props
+        if existing_bucket_obj is not None:
+            self._values["existing_bucket_obj"] = existing_bucket_obj
 
     @builtins.property
     def state_machine_props(self) -> aws_cdk.aws_stepfunctions.StateMachineProps:
@@ -205,29 +248,16 @@ class S3ToStepFunctionProps():
         default
         :default: - None
         """
-        return self._values.get('state_machine_props')
+        return self._values.get("state_machine_props")
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
-        """Optional user provided props to override the default props.
-
-        If ``deploy`` is set to true only then this property is required
+        """User provided props to override the default props for the S3 Bucket.
 
         default
         :default: - Default props are used
         """
-        return self._values.get('bucket_props')
-
-    @builtins.property
-    def deploy_bucket(self) -> typing.Optional[bool]:
-        """Whether to create a S3 Bucket or use an existing S3 Bucket.
-
-        If set to false, you must provide S3 Bucket as ``existingBucketObj``
-
-        default
-        :default: - true
-        """
-        return self._values.get('deploy_bucket')
+        return self._values.get("bucket_props")
 
     @builtins.property
     def deploy_cloud_trail(self) -> typing.Optional[bool]:
@@ -236,7 +266,7 @@ class S3ToStepFunctionProps():
         default
         :default: - true
         """
-        return self._values.get('deploy_cloud_trail')
+        return self._values.get("deploy_cloud_trail")
 
     @builtins.property
     def event_rule_props(self) -> typing.Optional[aws_cdk.aws_events.RuleProps]:
@@ -245,18 +275,16 @@ class S3ToStepFunctionProps():
         default
         :default: - None
         """
-        return self._values.get('event_rule_props')
+        return self._values.get("event_rule_props")
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        """Existing instance of S3 Bucket object.
-
-        If ``deployBucket`` is set to false only then this property is required
+        """Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
 
         default
         :default: - None
         """
-        return self._values.get('existing_bucket_obj')
+        return self._values.get("existing_bucket_obj")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -265,7 +293,9 @@ class S3ToStepFunctionProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'S3ToStepFunctionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "S3ToStepFunctionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
